#!/bin/sh
# Quick and Dirty Install Script
# for gShield

mkdir -p /etc/firewall
cp -iv * /etc/firewall
mv /etc/firewall/gShield.conf /etc
echo "------------------------"
echo "----- Done! ------------"
echo "------------------------"
echo ""
echo "Files installed as follows: "
echo "Configuration ----->      /etc/gShield.conf"
echo "Main script, etc -->	/etc/firewall/"

echo "adjusting permissions"

chmod 750 /etc/firewall
chmod 640 /etc/firewall/*
chmod 700 /etc/firewall/gShield.rc
